==> serendipity_1.0.4.orig.tar.gz: serendipity/plugins/serendipity_event_karma/lang_pl.inc.php <==
<?php # $Id: lang_en.inc.php 690 2005-11-13 04:49:04Z elf2000 $

/**
 *  @version $Revision: 690 $
 *  @author Kostas CoSTa Brzezinski <costa@kofeina.net>
 *  EN-Revision: Revision of lang_en.inc.php
 */

@define('PLUGIN_KARMA_NAME', 'Karma');
@define('PLUGIN_KARMA_BLAHBLAH', 'Niechaj odwiedzajcy Twoj stron oceni jako Twoich wpisw');
@define('PLUGIN_KARMA_VOTETEXT', 'Karma dla tego artykuu: ');
@define('PLUGIN_KARMA_RATE', 'Oce ten wpis: %s');
@define('PLUGIN_KARMA_VOTEPOINT_1', 'Bardzo dobry!');
@define('PLUGIN_KARMA_VOTEPOINT_2', 'Dobry');
@define('PLUGIN_KARMA_VOTEPOINT_3', 'Neutralny');
@define('PLUGIN_KARMA_VOTEPOINT_4', 'Nie interesujcy');
@define('PLUGIN_KARMA_VOTEPOINT_5', 'Zy');
@define('PLUGIN_KARMA_VOTED', 'Twoja ocena "%s" zostaa zachowana.');
@define('PLUGIN_KARMA_INVALID', 'Twoje ocenianie nie przebiego prawidowo.');
@define('PLUGIN_KARMA_ALREADYVOTED', 'Twoja ocena zostaa ju zachowana.');
@define('PLUGIN_KARMA_NOCOOKIE', 'Twoja przegldarka musi obsugiwa ciasteczka (cookies) by mg (moga) oceni wpis.');
@define('PLUGIN_KARMA_CLOSED', 'Gosuj na wpisy nie starsze ni %s dni!');
@define('PLUGIN_KARMA_ENTRYTIME', 'Czas gosowania po publikacji');
@define('PLUGIN_KARMA_VOTINGTIME', 'Czas gosowania');
@define('PLUGIN_KARMA_ENTRYTIME_BLAHBLAH', 'Jak dugo (w minutach) po publikacji Twojego wpisu bdzie moliwe gosowanie bez ogranicze? Standardowo: 1440 (jeden dzie)');
@define('PLUGIN_KARMA_VOTINGTIME_BLAHBLAH', 'Czas (w minutach) jaki musi min pomidzy gosowaniami. Stosowane tylko gdy minie okres czasu zdefiniowany powyej. Standardowo: 5');
@define('PLUGIN_KARMA_TIMEOUT', 'Ochrona przed floodem: Inny uytkownik dopiero co odda swj gos. Prosz odczeka %s minut.');
@define('PLUGIN_KARMA_CURRENT', 'Aktualna karma: %2$s, %3$s gosw');
@define('PLUGIN_KARMA_EXTENDEDONLY', 'Tylko przy Rozszerzonej treci wpisu');
@define('PLUGIN_KARMA_EXTENDEDONLY_BLAHBLAH', 'Poka gosowanie Karma po wywietleniu Rozszerzonej treci wpisu');
@define('PLUGIN_KARMA_MAXKARMA', 'Czas gosowania Karma');
@define('PLUGIN_KARMA_MAXKARMA_BLAHBLAH', 'Zezwl na gosowanie Karma tylko dla wpisw, ktre maj nie wicej ni X dni (standardowo: 7)');
@define('PLUGIN_KARMA_LOGGING', 'Logowanie gosw');
@define('PLUGIN_KARMA_LOGGING_BLAHBLAH', 'Czy oddane gosy maj by zapisane w logach?');
@define('PLUGIN_KARMA_ACTIVE', 'Wczy gosowanie Karma?');
@define('PLUGIN_KARMA_ACTIVE_BLAHBLAH', 'Czy gosowanie Karma ma by wczone?');
@define('PLUGIN_KARMA_VISITS', 'Wczy ledzenie wizyt?');
@define('PLUGIN_KARMA_VISITS_BLAHBLAH', 'Czy wywietlenia wpisu maj by zliczane i wywietlane?');
@define('PLUGIN_KARMA_VISITSCOUNT', ' %4$s wywietle');
@define('PLUGIN_KARMA_STATISTICS_VISITS_TOP', 'Najczciej wywietlane wpisy');
@define('PLUGIN_KARMA_STATISTICS_VISITS_BOTTOM', 'Najrzadziej wywietlane wpisy');
@define('PLUGIN_KARMA_STATISTICS_VOTES_TOP', 'Wpisy, na ktre oddano najwicej gosw');
@define('PLUGIN_KARMA_STATISTICS_VOTES_BOTTOM', 'Wpisy, na ktre oddano najmniej gosw');
@define('PLUGIN_KARMA_STATISTICS_POINTS_TOP', 'Najwyej ocenione wpisy');
@define('PLUGIN_KARMA_STATISTICS_POINTS_BOTTOM', 'Najniej ocenione wpisy');
@define('PLUGIN_KARMA_STATISTICS_VISITS_NO', 'wizyt');
@define('PLUGIN_KARMA_STATISTICS_VOTES_NO', 'gosw');
@define('PLUGIN_KARMA_STATISTICS_POINTS_NO', 'punktw');

?>

==> serendipity_1.1.4.orig.tar.gz: serendipity/plugins/serendipity_event_karma/lang_pl.inc.php <==
<?php # $Id: lang_pl.inc.php 1549 2006-12-20 18:26:51Z garvinhicking $

/**
 *  @version $Revision: 1549 $
 *  @author Kostas CoSTa Brzezinski <costa@kofeina.net>
 *  EN-Revision: Revision of lang_en.inc.php
 */

@define('PLUGIN_KARMA_NAME', 'Karma');
@define('PLUGIN_KARMA_BLAHBLAH', 'Niechaj odwiedzajcy Twoj stron oceni jako Twoich wpisw');
@define('PLUGIN_KARMA_VOTETEXT', 'Karma dla tego artykuu: ');
@define('PLUGIN_KARMA_RATE', 'Oce ten wpis: %s');
@define('PLUGIN_KARMA_VOTEPOINT_1', 'Bardzo dobry!');
@define('PLUGIN_KARMA_VOTEPOINT_2', 'Dobry');
@define('PLUGIN_KARMA_VOTEPOINT_3', 'Neutralny');
@define('PLUGIN_KARMA_VOTEPOINT_4', 'Nie interesujcy');
@define('PLUGIN_KARMA_VOTEPOINT_5', 'Zy');
@define('PLUGIN_KARMA_VOTED', 'Twoja ocena "%s" zostaa zachowana.');
@define('PLUGIN_KARMA_INVALID', 'Twoje ocenianie nie przebiego prawidowo.');
@define('PLUGIN_KARMA_ALREADYVOTED', 'Twoja ocena zostaa ju zachowana.');
@define('PLUGIN_KARMA_NOCOOKIE', 'Twoja przegldarka musi obsugiwa ciasteczka (cookies) by mg (moga) oceni wpis.');
@define('PLUGIN_KARMA_CLOSED', 'Gosuj na wpisy nie starsze ni %s dni!');
@define('PLUGIN_KARMA_ENTRYTIME', 'Czas gosowania po publikacji');
@define('PLUGIN_KARMA_VOTINGTIME', 'Czas gosowania');
@define('PLUGIN_KARMA_ENTRYTIME_BLAHBLAH', 'Jak dugo (w minutach) po publikacji Twojego wpisu bdzie moliwe gosowanie bez ogranicze? Standardowo: 1440 (jeden dzie)');
@define('PLUGIN_KARMA_VOTINGTIME_BLAHBLAH', 'Czas (w minutach) jaki musi min pomidzy gosowaniami. Stosowane tylko gdy minie okres czasu zdefiniowany powyej. Standardowo: 5');
@define('PLUGIN_KARMA_TIMEOUT', 'Ochrona przed floodem: Inny uytkownik dopiero co odda swj gos. Prosz odczeka %s minut.');
@define('PLUGIN_KARMA_CURRENT', 'Aktualna karma: %2$s, gosw: %3$s');
@define('PLUGIN_KARMA_EXTENDEDONLY', 'Tylko przy Rozszerzonej treci wpisu');
@define('PLUGIN_KARMA_EXTENDEDONLY_BLAHBLAH', 'Poka gosowanie Karma po wywietleniu Rozszerzonej treci wpisu');
@define('PLUGIN_KARMA_MAXKARMA', 'Czas gosowania Karma');
@define('PLUGIN_KARMA_MAXKARMA_BLAHBLAH', 'Zezwl na gosowanie Karma tylko dla wpisw, ktre maj nie wicej ni X dni (standardowo: 7)');
@define('PLUGIN_KARMA_LOGGING', 'Logowanie gosw');
@define('PLUGIN_KARMA_LOGGING_BLAHBLAH', 'Czy oddane gosy maj by zapisane w logach?');
@define('PLUGIN_KARMA_ACTIVE', 'Wczy gosowanie Karma?');
@define('PLUGIN_KARMA_ACTIVE_BLAHBLAH', 'Czy gosowanie Karma ma by wczone?');
@define('PLUGIN_KARMA_VISITS', 'Wczy ledzenie wizyt?');
@define('PLUGIN_KARMA_VISITS_BLAHBLAH', 'Czy wywietlenia wpisu maj by zliczane i wywietlane?');
@define('PLUGIN_KARMA_VISITSCOUNT', ' wywietle: %4$s');
@define('PLUGIN_KARMA_STATISTICS_VISITS_TOP', 'Najczciej wywietlane wpisy');
@define('PLUGIN_KARMA_STATISTICS_VISITS_BOTTOM', 'Najrzadziej wywietlane wpisy');
@define('PLUGIN_KARMA_STATISTICS_VOTES_TOP', 'Wpisy, na ktre oddano najwicej gosw');
@define('PLUGIN_KARMA_STATISTICS_VOTES_BOTTOM', 'Wpisy, na ktre oddano najmniej gosw');
@define('PLUGIN_KARMA_STATISTICS_POINTS_TOP', 'Najwyej ocenione wpisy');
@define('PLUGIN_KARMA_STATISTICS_POINTS_BOTTOM', 'Najniej ocenione wpisy');
@define('PLUGIN_KARMA_STATISTICS_VISITS_NO', 'wizyt');
@define('PLUGIN_KARMA_STATISTICS_VOTES_NO', 'gosw');
@define('PLUGIN_KARMA_STATISTICS_POINTS_NO', 'punktw');

@define('PLUGIN_KARMA_STARRATING', 'Wczy induwidualne ocenianie w tym wpisie?');
?>
